@@ -19,7 +19,7 @@ from .events import *
 from .loyalty_ticker import *
 from .disabled_commands import *
 from .duel import *
-from .command_server import start_command_server
+from .command_server import start_command_server, SilentMessage, stop_command_server
 from .modloader import *
 from .disabled_mods import *
 from .data import *
@@ -32,5 +32,5 @@ from .event_util import *
 from .extra_configs import *
 from .pubsub import *
 
-BOT_VERSION = (2, 1, 2)
+BOT_VERSION = (2, 1, 4)
 _set_bot_package_path(__path__[0])
